#[non_exhaustive]pub enum ProtocolError {
UnexpectedEof {
needed: usize,
},
InvalidValue(&'static str),
InvalidUtf8(Utf8Error),
VarintTooLong {
max: usize,
},
UnsupportedVersion {
api_key: i16,
version: i16,
},
SchemaMismatch(&'static str),
}Expand description
Errors that can occur during wire-protocol encoding or decoding.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnexpectedEof
Decode reached end of buffer before the expected number of bytes.
InvalidValue(&'static str)
Decoded a value that the schema says is impossible (e.g. negative array length).
InvalidUtf8(Utf8Error)
Decoded UTF-8 bytes that are not valid UTF-8.
VarintTooLong
Decoded a varint that exceeds the maximum legal length.
UnsupportedVersion
Encountered an unknown API version for a known API key.
SchemaMismatch(&'static str)
Schema version requested is not within the message’s supported range.