pub struct ApiVersionsRequest {
pub client_software_name: String,
pub client_software_version: String,
pub unknown_tagged_fields: UnknownTaggedFields,
}Fields
client_software_name: Stringclient_software_version: Stringunknown_tagged_fields: UnknownTaggedFieldsTrait Implementations
Sourceimpl<'a> Arbitrary<'a> for ApiVersionsRequest
impl<'a> Arbitrary<'a> for ApiVersionsRequest
Sourcefn arbitrary(u: &mut Unstructured<'a>) -> Result<Self>
fn arbitrary(u: &mut Unstructured<'a>) -> Result<Self>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(u: Unstructured<'a>) -> Result<Self, Error>
fn arbitrary_take_rest(u: Unstructured<'a>) -> Result<Self, Error>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourcefn size_hint(depth: usize) -> (usize, Option<usize>)
fn size_hint(depth: usize) -> (usize, Option<usize>)
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourcefn try_size_hint(
depth: usize,
) -> Result<(usize, Option<usize>), MaxRecursionReached>
fn try_size_hint( depth: usize, ) -> Result<(usize, Option<usize>), MaxRecursionReached>
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourceimpl Clone for ApiVersionsRequest
impl Clone for ApiVersionsRequest
Sourcefn clone(&self) -> ApiVersionsRequest
fn clone(&self) -> ApiVersionsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ApiVersionsRequest
impl Debug for ApiVersionsRequest
Sourceimpl Decode<'_> for ApiVersionsRequest
impl Decode<'_> for ApiVersionsRequest
Sourceimpl Default for ApiVersionsRequest
impl Default for ApiVersionsRequest
Sourcefn default() -> ApiVersionsRequest
fn default() -> ApiVersionsRequest
Returns the “default value” for a type. Read more
Sourceimpl Encode for ApiVersionsRequest
impl Encode for ApiVersionsRequest
impl Eq for ApiVersionsRequest
Sourceimpl PartialEq for ApiVersionsRequest
impl PartialEq for ApiVersionsRequest
Sourcefn eq(&self, other: &ApiVersionsRequest) -> bool
fn eq(&self, other: &ApiVersionsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ProtocolRequest for ApiVersionsRequest
impl ProtocolRequest for ApiVersionsRequest
Sourceconst MIN_VERSION: i16 = MIN_VERSION
const MIN_VERSION: i16 = MIN_VERSION
Minimum protocol version this Rust type supports.
Sourceconst MAX_VERSION: i16 = MAX_VERSION
const MAX_VERSION: i16 = MAX_VERSION
Maximum protocol version this Rust type supports.
Sourceconst FLEXIBLE_MIN: i16 = FLEXIBLE_MIN
const FLEXIBLE_MIN: i16 = FLEXIBLE_MIN
First version that uses flexible (KIP-482) framing.
i16::MAX for never-flexible messages.Sourcetype Response = ApiVersionsResponse
type Response = ApiVersionsResponse
Matching response type from
crabka-protocol.impl StructuralPartialEq for ApiVersionsRequest