pub struct ApiVersion {
pub api_key: i16,
pub min_version: i16,
pub max_version: i16,
pub unknown_tagged_fields: UnknownTaggedFields,
}Fields
api_key: i16min_version: i16max_version: i16unknown_tagged_fields: UnknownTaggedFieldsTrait Implementations
Sourceimpl<'a> Arbitrary<'a> for ApiVersion
impl<'a> Arbitrary<'a> for ApiVersion
Sourcefn arbitrary(u: &mut Unstructured<'a>) -> Result<Self>
fn arbitrary(u: &mut Unstructured<'a>) -> Result<Self>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(u: Unstructured<'a>) -> Result<Self, Error>
fn arbitrary_take_rest(u: Unstructured<'a>) -> Result<Self, Error>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourcefn size_hint(depth: usize) -> (usize, Option<usize>)
fn size_hint(depth: usize) -> (usize, Option<usize>)
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourcefn try_size_hint(
depth: usize,
) -> Result<(usize, Option<usize>), MaxRecursionReached>
fn try_size_hint( depth: usize, ) -> Result<(usize, Option<usize>), MaxRecursionReached>
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourceimpl Clone for ApiVersion
impl Clone for ApiVersion
Sourcefn clone(&self) -> ApiVersion
fn clone(&self) -> ApiVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ApiVersion
impl Debug for ApiVersion
Sourceimpl Decode<'_> for ApiVersion
impl Decode<'_> for ApiVersion
Sourceimpl Default for ApiVersion
impl Default for ApiVersion
Sourcefn default() -> ApiVersion
fn default() -> ApiVersion
Returns the “default value” for a type. Read more
Sourceimpl Encode for ApiVersion
impl Encode for ApiVersion
impl Eq for ApiVersion
Sourceimpl PartialEq for ApiVersion
impl PartialEq for ApiVersion
Sourcefn eq(&self, other: &ApiVersion) -> bool
fn eq(&self, other: &ApiVersion) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ApiVersion